Informix — SQLAlchemy 0.8 Documentation

# SQLAlchemy 0.8 Documentation

Search:
Release: 0.8.5 | Release Date: February 19, 2014

# Informix

Support for the Informix database.

## DBAPI Support

The following dialect/DBAPI options are available. Please refer to individual DBAPI sections for connect information.

- informixdb

Note

The Informix dialect functions on current SQLAlchemy versions but is not regularly tested, and may have many issues and caveats not currently handled.

## informixdb

Support for the Informix database via the informixdb driver.

### DBAPI

Documentation and download information (if applicable) for informixdb is available at: http://informixdb.sourceforge.net/

### Connecting

Connect String:

    informix+informixdb://user:password@host/dbname